NumberCustomVariableValue class final
A numeric custom variable value.
- Inheritance
-
- Object
- CustomVariableValue
- NumberCustomVariableValue
Constructors
- NumberCustomVariableValue(double value)
-
Creates a numeric custom variable value.
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValue → String
-
Returns the string representation of this value.
no setteroverride
- value → double
-
The numeric value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override