PurchaseLogicResult enum

Result of a custom purchase or restore operation performed by the app.

Inheritance
Available extensions

Values

success → const PurchaseLogicResult

The purchase or restore completed successfully.

cancellation → const PurchaseLogicResult

The user cancelled the purchase.

error → const PurchaseLogicResult

An error occurred during the purchase or restore.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PurchaseLogicResult>
A constant List of the values in this enum, in order of their declaration.