CustomerCenterPromotionalOfferSucceeded typedef

CustomerCenterPromotionalOfferSucceeded = void Function(CustomerInfo customerInfo, StoreTransaction transaction, String offerId)

Called when a promotional offer purchase completes successfully in the Customer Center, providing the resulting customer info, transaction, and the promotional offer identifier.

Implementation

typedef CustomerCenterPromotionalOfferSucceeded = void Function(
  CustomerInfo customerInfo,
  StoreTransaction transaction,
  String offerId,
);