PaywallViewMethodHandler class

Constructors

PaywallViewMethodHandler(dynamic onPurchaseStarted(Package rcPackage)?, dynamic onPurchaseCompleted(CustomerInfo customerInfo, StoreTransaction storeTransaction)?, dynamic onPurchaseCancelled()?, dynamic onPurchaseError(PurchasesError)?, dynamic onRestoreCompleted(CustomerInfo customerInfo)?, dynamic onRestoreError(PurchasesError)?, dynamic onDismiss()?, {PaywallPurchaseLogic? purchaseLogic, MethodChannel? methodChannel})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel?
final
onDismiss → dynamic Function()?
final
onPurchaseCancelled → dynamic Function()?
final
onPurchaseCompleted → dynamic Function(CustomerInfo customerInfo, StoreTransaction storeTransaction)?
final
onPurchaseError → dynamic Function(PurchasesError)?
final
onPurchaseStarted → dynamic Function(Package rcPackage)?
final
onRestoreCompleted → dynamic Function(CustomerInfo customerInfo)?
final
onRestoreError → dynamic Function(PurchasesError)?
final
purchaseLogic PaywallPurchaseLogic?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleMethodCall(MethodCall call) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited