AndroidPaywallPresentationStyle class final
Controls how the paywall is presented on Android.
Uses a private constructor with static constants so that new values can be added in the future without breaking existing code.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- fullScreen → const AndroidPaywallPresentationStyle
- Presents the paywall as a full-screen activity (default Android behavior).