PaywallPurchaseLogic class abstract

Interface for custom purchase logic when purchasesAreCompletedBy is set to myApp.

When provided to a PaywallView, the paywall will delegate purchase and restore operations to this implementation instead of using RevenueCat's default flow.

Constructors

PaywallPurchaseLogic()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performPurchase(Package packageToPurchase) → Future<PurchaseLogicResult>
Called when the user initiates a purchase from the paywall.
performRestore() → Future<PurchaseLogicResult>
Called when the user initiates a restore from the paywall.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited